# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['max_ard', 'max_ard.commands', 'max_ard.outputs']

package_data = \
{'': ['*']}

install_requires = \
['PyJWT>=2.1.0,<3.0.0',
 'Shapely>=1.7.1,<2.0.0',
 'backports.cached-property>=1.0.1,<2.0.0',
 'boto3>=1.17.73,<2.0.0',
 'click>=7.0.0,<8.0.0',
 'maxar-canvas-grid>=0.0.12,<0.0.13',
 'pydantic>=1.7.4,<2.0.0',
 'requests-oauthlib>=1.3.0,<2.0.0',
 'requests>=2.25.1,<3.0.0',
 's3fs>=0.4.2,<0.5.0']

extras_require = \
{'full': ['rasterio>=1.2.3,<2.0.0', 'Fiona>=1.8.19,<2.0.0']}

entry_points = \
{'console_scripts': ['max-ard = max_ard.commands.command:max_ard']}

setup_kwargs = {
    'name': 'max-ard',
    'version': '1.0.0a2',
    'description': 'ARD SDK and CLI tools',
    'long_description': "# max_ard\n\nA Python SDK and CLI for working with ARD Imagery\n\n## Introduction\n\n`max_ard` consists of a Python SDK for selecting, ordering, and working with Maxar ARD imagery and a set of CLI tools  for common tasks.\n\n## Installation\n\nFor now, download release files from the release section in Github then install it with `pip`:\n\n`pip install max-ard.<other stuff>`\n\nThis will be the official way to install:\n\n`pip install max-ard --extra-index-url https://ard.maxar.com/packages`\n\n## Prerequisites\n\nIf you are using the SDK or CLI to access data in an S3 bucket, you will need to configure your AWS credentials locally. If you install the AWS CLI tools and and can `aws s3 ls <bucket>` then you're set to go.\n\nTo interact with the ARD services, you also need to have ARD account credentials. Currently we store the credentials locally in a file in your home directory called `.ard-config`. It should contain:\n\n```shell\n[ard]\nuser_name = <your user name>\nuser_password = <your password>\n```\n\nThe CLI tools can be used to create this file:\n\n`max-ard login --username <your username> --password <your password`\n\nTools for browsing ARD data currently have an optimization that uses GBDX systems. If you do not have GBDX credentials the optimization is skipped. This dependency will be moved to use the ARD system in the future.\n\n## Documentation\n\nThe most current general ARD documentation is here for now:\n\nhttp://ard-docs.s3-website-us-east-1.amazonaws.com/dev/\n\nGeneral ARD documentation will be at https://ard.maxar.com/docs.\n\nThe documents for the SDK  are in the `/docs` directory, but will be published to  https://ard.maxar.com/sdk-docs soon.\n\n## Development\n\nThis project uses Poetry for managing development. To get started using Poetry, ensure it is installed as per: https://python-poetry.org/docs/#installation.\n\nTo get started with development, create a local virtual env and install all the dependencies:\n\n```shell\npoetry config virtualenvs.in-project true --local\npoetry install --extras full\n```\n\nIf during development a new dependency is required, it can be added with the following:\n\n```shell\npoetry add <pkg_name> [--dev]\n```\n\n### Run Tests\n\nThere are some required env vars for running the tests, they can be found in the [.env-sample](.env-sample) file. It is up to the user to have those env vars active before running the tests. This file can be copied to a `.env` file (ARD creds need to be added), to be used with tools that support the format.\n\nTo run the tests prior to creating a PR:\n\n```shell\npoetry run ./scripts/tests\n```\n\n## Releases\n\nThe script for making a new release is [scripts/release](scripts/release). This can me called directly as follows:\n\n```shell\n./scripts/release patch|minor|major|prepatch|preminor|premajor|prerelease\n```\n\nThe semver argument will be passed to Poetry, see the Poetry docs for the different arguments: https://python-poetry.org/docs/cli/#version\n\nFor pre-releases, having a current version of 0.0.1, a pre-release version can be bumped by using `./scripts/release prepatch` or `./scripts/release prerelease`, which will result in `0.0.2-alpha.0`. Then to bump to `0.0.2`, run `poetry version patch`.\n\nHowever, if you want to do a pre-release for a major or minor version, use the `premajor` or `preminor` argument. Then you can use `major` or `minor` to bump to the final version. Check the Poetry docs for more details.\n\n## Update Documentation\n\nTo trigger a build of the docs and to publish to S3, run the following script:\n\n```shell\n./scripts/update_docs\n```\n\nThis script will create a branch called `update_docs`, reset it to the current `master` branch, and push. Which will trigger the CircleCI workflow to build and publish the latest documentation.\n",
    'author': 'Marc Pfister',
    'author_email': 'marc.pfister@maxar.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://ard.maxar.com/sdk-docs/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
